SWDEV-546347-Added tests for Module Management APIs (#539)
* SWDEV-546347-Added tests for hipModuleGetFunctionCount * SWDEV-546347-Added tests for hipModuleLoadFatBinary * SWDEV-546347-Added 3 more tests for hipModuleLoadFatBinary * SWDEV-546347-Updated hipModuleLoadFatBinary.cc * SWDEV-546347-Added test for hipModuleGetLoadingMode API * SWDEV-546347-Clang-format issues * SWDEV-546347-Removed tests of hipModuleGetLoadingMode API * SWDEV-546347 - Updated CMake file * SWDEV-546347-Addressed review comments * SWDEV-546347-Updated CmakeLists * SWDEV-546347-Addressed review comments * SWDEV-546347-Addressed Review comments --------- Co-authored-by: SrinivasRao Gollamandala <Srinivasarao.Gollamandala@amd.com> Co-authored-by: systems-assistant[bot] <systems-assistant[bot]@users.noreply.github.com> Co-authored-by: jainprad <92369414+jainprad@users.noreply.github.com> Co-authored-by: Rambabu Swargam <rambabu.swargam@amd.com>
This commit is contained in:
committed by
GitHub
parent
446fbd3191
commit
9021b43cd1
@@ -0,0 +1,29 @@
|
||||
/*
|
||||
Copyright (c) 2025 Advanced Micro Devices, Inc. All rights reserved.
|
||||
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||
of this software and associated documentation files (the "Software"), to deal
|
||||
in the Software without restriction, including without limitation the rights
|
||||
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||
copies of the Software, and to permit persons to whom the Software is
|
||||
furnished to do so, subject to the following conditions:
|
||||
The above copyright notice and this permission notice shall be included in
|
||||
all copies or substantial portions of the Software.
|
||||
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANNTY OF ANY KIND, EXPRESS OR
|
||||
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||
FITNNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||
LIABILITY, WHETHER INN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||
OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
#include "hip/hip_runtime.h"
|
||||
|
||||
extern "C" __device__ void hello_world_2(float* a, float* b) {
|
||||
int tx = threadIdx.x;
|
||||
b[tx] = a[tx];
|
||||
}
|
||||
|
||||
extern "C" __global__ void hello_world(float* a, float* b) {
|
||||
int tx = threadIdx.x;
|
||||
b[tx] = a[tx];
|
||||
}
|
||||
Reference in New Issue
Block a user